@@ -33,7 +33,7 @@ void JSSpell::initType( KJSContext *ctx )
     initialized = true;
 
     g_spellProto = new KJSPrototype();
-    g_spellProto->defineProperty( ctx, QString( "available" ), spellGetAvailable );
+    g_spellProto->defineProperty( ctx, QStringLiteral( "available" ), spellGetAvailable );
 }
 
 KJSObject JSSpell::object( KJSContext *ctx )
