@@ -11,30 +11,14 @@
 
 #include "converter.h"
 
-#include <kaboutdata.h>
-#include <klocale.h>
+#include <KAboutData>
+#include <KLocalizedString>
 #include <kconfigdialog.h>
 
-static KAboutData createAboutData()
-{
-    KAboutData aboutData(
-         "okular_fictionbook",
-         "okular_fictionbook",
-         ki18n( "Fiction Book Backend" ),
-         "0.1.5",
-         ki18n( "A renderer for FictionBook eBooks" ),
-         KAboutData::License_GPL,
-         ki18n( "© 2007-2008 Tobias Koenig" )
-    );
-    aboutData.addAuthor( ki18n( "Tobias Koenig" ), KLocalizedString(), "tokoe@kde.org" );
-
-    return aboutData;
-}
-
-OKULAR_EXPORT_PLUGIN( FictionBookGenerator, createAboutData() )
+OKULAR_EXPORT_PLUGIN(FictionBookGenerator, "libokularGenerator_fb.json")
 
 FictionBookGenerator::FictionBookGenerator( QObject *parent, const QVariantList &args )
-    : Okular::TextDocumentGenerator( new FictionBook::Converter, "okular_fictionbook_generator_settings", parent, args )
+    : Okular::TextDocumentGenerator( new FictionBook::Converter, QStringLiteral("okular_fictionbook_generator_settings"), parent, args )
 {
 }
 
@@ -42,5 +26,7 @@ void FictionBookGenerator::addPages( KConfigDialog* dlg )
 {
     Okular::TextDocumentSettingsWidget *widget = new Okular::TextDocumentSettingsWidget();
 
-    dlg->addPage( widget, generalSettings(), i18n("FictionBook"), "okular-fb2", i18n("FictionBook Backend Configuration") );
+    dlg->addPage( widget, generalSettings(), i18n("FictionBook"), QStringLiteral("okular-fb2"), i18n("FictionBook Backend Configuration") );
 }
+#include "generator_fb.moc"
+
