@@ -10,9 +10,10 @@
 #ifndef _EMBEDDEDFILESDIALOG_H_
 #define _EMBEDDEDFILESDIALOG_H_
 
-#include <kdialog.h>
+#include <QDialog>
 
 class QTreeWidget;
+class QPushButton;
 class QTemporaryFile;
 class QTreeWidgetItem;
 
@@ -21,13 +22,13 @@ class Document;
 class EmbeddedFile;
 }
 
-class EmbeddedFilesDialog : public KDialog
+class EmbeddedFilesDialog : public QDialog
 {
 Q_OBJECT
 	public:
 		EmbeddedFilesDialog(QWidget *parent, const Okular::Document *document);
 
-	private slots:
+    private Q_SLOTS:
 		void saveFile();
 		void attachViewContextMenu( const QPoint& pos );
 		void updateSaveButton();
@@ -39,6 +40,10 @@ Q_OBJECT
 		void viewFile( Okular::EmbeddedFile* );
 
 		QTreeWidget *m_tw;
+
+                
+		QPushButton *mUser1Button;
+		QPushButton *mUser2Button;
 		QList< QSharedPointer<QTemporaryFile> > m_openedFiles;
 };
 
